@@ -48,13 +48,7 @@ NULL
 
 devtools_default_options <- list(
   devtools.path = "~/R-dev",
-  devtools.install.args = "",
-  devtools.name = "Your name goes here",
-  devtools.desc.author = 'person("First", "Last", email = "first.last@example.com", role = c("aut", "cre"))',
-  devtools.desc.license = "What license is it under?",
-  devtools.desc.suggests = NULL,
-  devtools.desc = list(),
-  devtools.revdep.libpath = file.path(tempdir(), "R-lib")
+  devtools.install.args = ""
 )
 
 .onLoad <- function(libname, pkgname) {
@@ -64,11 +58,3 @@ devtools_default_options <- list(
 
   invisible()
 }
-
-.onAttach <- function(libname, pkgname) {
-  env <- as.environment(paste0("package:", pkgname))
-  env[[".conflicts.OK"]] <- TRUE
-  usethis_lib <- dirname(getNamespaceInfo("usethis", "path"))
-  suppressPackageStartupMessages((
-    get("library", baseenv()))("usethis", lib.loc = usethis_lib))
-}
